@@ -18,6 +18,8 @@ from dbt.exceptions import DatabaseException, FailedToConnectException, RuntimeE
 from dbt.helper_types import Port
 from trino.transaction import IsolationLevel
 
+from dbt.adapters.trino.__version__ import version
+
 logger = AdapterLogger("Trino")
 PREPARED_STATEMENTS_ENABLED_DEFAULT = True
 
@@ -281,7 +283,7 @@ class ConnectionWrapper(object):
         self._prepared_statements_enabled = prepared_statements_enabled
 
     def cursor(self):
-        self._cursor = self.handle.cursor(experimental_python_types=True)
+        self._cursor = self.handle.cursor()
         return self
 
     def cancel(self):
@@ -427,7 +429,7 @@ class TrinoConnectionManager(SQLConnectionManager):
             auth=credentials.trino_auth(),
             max_attempts=credentials.retries,
             isolation_level=IsolationLevel.AUTOCOMMIT,
-            source="dbt-trino",
+            source=f"dbt-trino-{version}",
             verify=credentials.cert,
         )
         connection.state = "open"
